use crate::message::{Level, Message};
use crate::monitor::*;
use serde::Deserialize;

#[derive(Debug)]
pub struct WifiAvailability {
    config: WifiAvailabilityConfig,
}
#[derive(Debug, Deserialize)]
struct WifiAvailabilityConfig {
    iface: String,
    ssid: String,
    #[serde(default)]
    essid: Vec<String>,
    #[serde(default)]
    ping_targets: Vec<String>,
}

impl Monitor for WifiAvailability {
    fn new(
        config: &HashMap<String, serde_yaml::Value>,
    ) -> Result<Self, Box<dyn std::error::Error>> {
        let config_node = config
            .get("config")
            .unwrap_or(&serde_yaml::Mapping::new().into())
            .clone();
        let config =
            serde_yaml::from_value(config_node).expect("Invalid config for wifi_availability");

        let wa = WifiAvailability { config: config };
        // Activate iface
        //ip link set wlan0 up

        Ok(wa)
    }
    fn run(&mut self, sender: &mpsc::Sender<Message>) {
        // iw dev wlan0 link: get is connected
        // iw dev wlan0 scan: scan all networks

        for target in &self.config.ping_targets {
            use std::process::{Command, Stdio};
            let res = Command::new("ping")
                .args(vec!["-c", "3", "-I", &self.config.iface, target])
                .stdout(Stdio::null())
                .status()
                .expect("failed to execute process");

            if !res.success() {
                sender
                    .send(Message {
                        emitter: "wifi_availability".to_owned(),
                        msg_type: "ping.failed".to_owned(),
                        level: Level::Issue,
                        text: format!("Cannot ping {}", target),
                    })
                    .unwrap();
            }
        }

        std::thread::sleep(std::time::Duration::from_millis(2000))
    }
}
